@@ -1,7 +1,7 @@
 import seutils
 import os.path as osp, sys
 from contextlib import contextmanager
-from seutils import run_command, get_exitcode, Inode, split_mgm, N_COPY_RETRIES
+from seutils import run_command, get_exitcode, Inode, split_mgm
 logger = seutils.logger
 
 IS_INSTALLED = None
